@@ -34,17 +34,17 @@
 #include <tqvalidator.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcombobox.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <klineedit.h>
 #include <klineeditdlg.h>
-#include <klocale.h>
-#include <kmenubar.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemenubar.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <knuminput.h>
 #include <kprinter.h>
 #include <kurlrequester.h>
@@ -67,14 +67,14 @@ TQString tec452(const TQString &url, int count, const TQString &art, const TQStr
 
     TQFile f( filename );
     if ( !f.open( IO_ReadOnly ) )
-        return false;
+        return 0;
 
     //clearLabel();
 
     TQDomDocument doc( "KBarcodeLabel" );
     if ( !doc.setContent( &f ) ) {
         f.close();
-        return false;
+        return 0;
     }
     f.close();
 
@@ -435,7 +435,7 @@ while (res ==-1 ){
  	res=read(fd,buf,MAXDATASIZE);
     	}
 temp = TQString(buf);
-//qDebug ("serial: "+temp+"\n");
+//tqDebug ("serial: "+temp+"\n");
 // LF =    = 10
 // CR = \r = 13
 
